import {
  select,
  csv,
  scaleLinear,
  max,
  extent,
  scalePoint,
	axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const xValue = d => d.horsepower;
  const xAxisLabel='Horsepower'
  const yAxisLabel='Weight'
  const title='weight vs horsepower'
  const yValue = d => d.weight;
  const margin = {top: 60, right: 40, bottom: 77, left: 150};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  
  const yScale = scaleLinear()
  	.domain(extent(data,yValue))
  	.range([0, innerHeight])
    .nice()
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
 
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
    .tickPadding(15)
  	
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
    .tickPadding(15)
  
  const yAxisG=g.append('g')
    .call(yAxis)
      yAxisG 
  	.selectAll('.domain')
  		.remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
    xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 65)
  	.attr('x', innerWidth / 2)
  	.attr('fill', 'black')
  	.text(xAxisLabel)

	yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -80)
  	.attr('x', -innerHeight/2)
  	.attr('fill', 'black')
    .attr('text-anchor','middle')
  	.text(yAxisLabel)
    .attr('transform', 'rotate(-90)');
     
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
			.attr('cy', d => yScale(yValue(d)))
    	.attr('cx', d => xScale(xValue(d)))
      .attr('r', 10);
  
  g.append('text')
  	.attr('class', 'title')
  	.attr('y', -10)
  	.text(title)
  
};

csv('https://vizhub.com/Sergiop79/datasets/auto-mpg.csv').then(data => {
	data.forEach(d => {
  d.mpg=+d.mpg;
  d.cylinder=+d.cylinder;
  d.displacement=+d.displacement;
  d.horsepower=+d.horsepower;
  d.weight=+d.weight;
  d.acceleration=+d.acceleration;
  d.year=+d.year;
  
  })
  render(data);
});